export default {
  pageTitle: "Unequal access to water",
  pageSubtitle: "How societal factors shape vulnerability to water insecurity",
  readIn: 'Read in: ',
  components: {
    introNarrative: {
      paragraph1: `Imagine, for example, that you live in a big house in the suburbs where clean water flows out of every faucet. There’s enough water for you and your family to grow a nice garden every year. The public water supplier treats the water and maintains the distribution system regularly, so you know the water is safe for you to drink.`,
      paragraph2: `Now imagine you live in a small rural community on the outskirts of town. You have your own well, but in recent years, you and your neighbors have had to dig deeper and deeper to reach water. Dangerous metals,  originating from historical sources such as old industrial landfills and corroded copper pipes soldered with lead, are leaching into the water belowground, but you have no way of treating your water before your family drinks it. A nearby pond shrinks each summer and acquires a ghastly green hue as it’s choked by harmful algae blooms.`,
      paragraph3: `This scene may sound hard to believe, but inadequate access to clean water is the unfortunate reality for many Americans. More than 2.2 million Americans lack running water and basic plumbing in their home <a href='https://www.digdeep.org/draining' target='_blank'>(DigDeep, 2022)</a>, and roughly 3% of community water systems have severe issues with water quality <a href='https://www.nature.com/articles/s41467-021-23898-z' target='_blank'>(Mueller and Gasteyer, 2021)</a>. Limited access to clean water may be triggered by a single event, like the <a href='https://storymaps.arcgis.com/stories/7f105650f97e4b20839edb65de3b12ce' target='_blank'>derailing of the train carrying hazardous chemicals in East Palestine, Ohio,</a> or may be the long-term result of aging infrastructure, as was the case with the <a href='https://www.npr.org/sections/thetwo-way/2016/04/20/465545378/lead-laced-water-in-flint-a-step-by-step-look-at-the-makings-of-a-crisis' target='_blank'>dangerously high levels of lead in the drinking water of Flint, Michigan.</a>`,
      paragraph4: `Marginalized populations are often disproportionately affected by water insecurity. Communities of color and individuals living below the poverty line are frequently the hardest hit by <span class="tooltip-group"><span class="tooltip-span">water-related hazards,</span><span id='water-hazards-tooltip' class="tooltiptext"> A natural phenomenon and a situation where there is threat to life, health, environment, property, and society. Examples of water-related hazards include floods, hydrologic droughts and storm surges.</span></span> lacking the means to safeguard themselves adequately. They may face barriers to relocation or struggle to take time off work, cope with lost wages, or afford medical expenses. In the case of the Flint, Michigan, water crisis, black and low-income communities, who at the time made up <a href='https://apnews.com/general-news-7b2bcfdcc8d74ece9e0cb167a2239745' target='_blank'>57% and 42%</a> of Flint's population, respectively, were some of the socio-economically disadvantaged communities most affected by lead exposure. Regardless of the cause, the risk of experiencing water insecurity is closely related to the level of <span class="tooltip-group"><span class="tooltip-span">social vulnerability</span><span id='social-vulnerability-tooltip' class="tooltiptext">Conditions in which societal factors shape exposure to hazards, susceptibility to suffer harm, and ability to cope and recover from losses.</span></span>.`,
    },
    mapText: {
      title: "Vulnerability indicators across the Western states ",
      p1Title: "Household sizes",
      paragraph1: "Infrastructure and institutional factors are major determinants of access to and reliability of water delivery in the United States <a href='https://doi.org/10.1029/2023WR036284' target='_blank'>(Drakes and others, 2024)</a>. <a href='https://wires.onlinelibrary.wiley.com/doi/10.1002/wat2.1486' target='_blank'>Meehan and others (2020)</a> found 471,000 households or 1.1 million people lacked piped water access between 2013 and 2017, with the majority (73%) of these households located in metropolitan areas, and nearly half (47%) in the 50 largest urban areas. The reviewed literature showed indicators of household size, female-headed households, female population, and percentage of females in the labor force were all predominantly positively related and influential to water insecurity conditions. Displayed below is a county-level map of the average household size of occupied housing units. Counties with the greatest average household size, shown in dark blue, include Oglala Lakota County, South Dakota; Madison County, Idaho; and Todd County, South Dakota.",
      p2Title: "Income inequalities",
      paragraph2: "Low income and impoverished persons are more likely to experience conditions associated with water insecurity. Moreover, income inequality is a highly significant predictor of 'plumbing poverty,' meaning homes that lack complete indoor plumbing <a href='https://www.pnas.org/doi/abs/10.1073/pnas.2007361117' target='_blank'>(Meehan and others, 2020)</a>. The county-level map below displays median household income in the past 12 months (in 2022 inflation-adjusted dollars). Counties with the greatest median household income are shown in dark blue and include Santa Clara County, California; San Mateo County, California; and Marin County, California.",
      p3Title: "Renter disparities",
      paragraph3: "As median rent values go up, water insecurity tends to go down, likely reflecting greater access to resources for wealthier populations <a href='https://www.sciencebase.gov/catalog/item/63f79d49d34e4f7eda456572' target='_blank'>(Hines and others, 2023)</a>. That said, renters tend to be at a higher risk of losses from water-related hazards compared to homeowners. After disasters, renters are more likely to relocate and less likely to apply for and receive assistance. Renters also often lack the authority and means to enact structural changes to their homes for hazard mitigation, response, or recovery, which raises the hazard exposure and susceptibility of renters while lowering their capacity to cope <a href='https://doi.org/10.1016/j.ijdrr.2020.102010' target='_blank'>(Drakes and others, 2021) </a>. The county-level map below displays median gross rent. Counties with the greatest median gross rent, shown in dark green, include San Mateo County, California; Santa Clara County, California; and Marin County, California.",
      p4Title: "Hispanic populations",
      paragraph4: "Hispanic populations are at an increased risk of water insecurity <a href='https://www.sciencebase.gov/catalog/item/63f79d49d34e4f7eda456572' target='_blank'>(Hines and others, 2023)</a>. In some areas of the country, Hispanic households are more likely to experience 'plumbing poverty'—meaning homes that lack complete indoor plumbing <a href='https://www.pnas.org/doi/abs/10.1073/pnas.2007361117' target='_blank'>(Meehan and others, 2020)</a>—particularly in the Western United States. In fact, research shows that although Hispanic-headed households make up less than 13% of all U.S. households, they account for nearly 17% of households with incomplete plumbing <a href='https://doi.org/10.1080/24694452.2018.1530587' target='_blank'>(Deitz & Meehan, 2019)</a>. The county map below shows the percent of Hispanic populations. Counties with the greatest percent of Hispanic residents, shown in dark blue, include Kenedy County, Texas; Starr County, Texas; and Webb County, Texas. These areas are particularly affected by the combined challenges of water insecurity and plumbing poverty.",
      p5Title: "Disabled populations",
      paragraph5: "Special needs and disabled populations may live in places more exposed to water-related hazards <a href='https://www.sciencedirect.com/science/article/abs/pii/S0277953619301121' target='_blank'>(Chakraborty and others, 2019)</a> or experiencing unreliable or intermittent potable water supplies <a href='https://journals.plos.org/plosone/article?id=10.1371/journal.pone.0155043' target='_blank'>(White and others, 2016)</a>. For example, <a href='https://doi.org/10.1029/2023WR036284' target='_blank'>Drakes and others (2024)</a> found special needs and disabled populations were associated with a higher likelihood of water insecure conditions in the Western United States. However, only two studies have measured the relationship between disability and water insecurity, and the limited research on the topic was conducted only in the municipal water-use sector. The map below shows the percent of disabled persons in each county. Counties with the greatest percent of disabled individuals, shown in dark blue, include Catron County, New Mexico; Mora County, New Mexico; and Kinney County, Texas."
    },
    metaAnalysisText: {
      title: "Meta-analysis of social vulnerability to water insecurity",
      paragraph1: `Researchers in the USGS Social and Economic Drivers program <a href="https://www.usgs.gov/data/literature-summary-indicators-water-vulnerability-western-us-2000-2022" target="blank">identified factors of social vulnerability associated with conditions of water insecurity</a>. The team focused their analysis on studies between 2000 and 2022 that took place in the conterminous United States (lower 48 states) west of the Mississippi River. The Western states face a slew of water availability challenges, including increasing population growth, dependence on groundwater, and generally low precipitation (see <a href='https://pubs.usgs.gov/circ/2005/circ1261/pdf/C1261.pdf' target="blank">Anderson and Woosley 2005 </a> for a discussion of water availability in the Western United States).`,
      paragraph2: `The team found that a small subset of social vulnerability factors was well studied and was consistently associated with water insecurity. These factors included multiple demographic characteristics (age, race/ethnicity, family structure, gender, and language proficiency), dependence on specific sources and uses of water, wealth, and exposure to water-related hazards.`,
      paragraph3: `But these factors are not equally distributed across the Western United States. For example, certain races and ethnicities are more heavily concentrated in some geographic areas than in others. Similarly, some counties have much lower median household incomes than other counties do. Understanding where these vulnerable populations live is important information for water-resource managers to make equitable decisions about water availability and use. Some of the factors this study found as significant in Western States are described in more detail below.`
    },
    socialVulnerabilityText: {
      title: "Where do we go from here?",
      paragraph1: `A crucial and largely unexplored area of research is the <span class='tooltip-group'><span class='tooltip-span'>intersectionality</span><span id='intersectionality-tooltip' class='tooltiptext'>The complex, cumulative way in which the effects of multiple forms of discrimination combine, overlap, or intersect especially in the experiences of marginalized individuals or groups.</span></span> of social vulnerability factors. The factors evaluated by the researchers at USGS represent individual drivers of water insecurity, like household size or ethnicity. What about the people who experience multiple risk factors at the same time? For example, “Elderly people who have lower incomes are a unique population, existing at the overlap of, but distinct from, the elderly or lower income alone,” says Oronde Drakes, social geographer at USGS and lead author of the <span class="tooltip-group"><span class="tooltip-span">meta-analysis</span><span id="meta-analysis-tooltip" class="tooltiptext">Type of review study where researchers combine data from many different studies to try to identify bigger patterns across all the results.</span></span>. “The interaction of those social characteristics may well have different and significant impacts on water security than would be found exploring those social factors on their own.”`,
      paragraph2: "In this burgeoning field of social vulnerability to water insecurity, there is still much to learn. A deeper understanding of not only where water insecurity occurs, but also who is most vulnerable and why, will improve the ability to address  <span class='tooltip-group'><span class='tooltip-span'>environmental justice</span><span id='environmental-justice-tooltip' class='tooltiptext'>Scientific planning, activities, and information intended to support equitable access and use by all people who may be affected.</span></span> and equity issues in water resources."
    },
    teamText: {
      title: "About the team",
      paragraph1: "The USGS Social and Economic Drivers team consists of social scientists, geographers, and hydrologists who conduct interdisciplinary studies to understand the interactions and interdependencies of human and natural systems with respect to water use sectors. The purpose of this project is to predict and measure social vulnerabilities to water security to better assess and manage risks for adaptive water management."
    },
    chartText: {
      bubbleText: "Interact with the chart to explore evidence<br>for social vulnerability determinants.",
      bubbleLegend: `Many social vulnerability determinants have been studied. Some show positive <span class="legend-box positive"></span> relationships with water insecurity, some negative <span class="legend-box negative"></span>, and others unknown <span class="legend-box unknown"></span> <a href='https://www.sciencebase.gov/catalog/item/63f79d49d34e4f7eda456572' target='_blank'>(Hines and others, 2023</a>; <a href='https://doi.org/10.1029/2023WR036284' target='_blank'>Drakes and others, 2024)</a>`,
      bubbleYaxis: `The y-axis of the chart represents the level of agreement among studies where increased <b>consensus</b> indicates a majority of studies using the selected determinant recorded the same direction of influence on conditions of water insecurity and <b>inconclusive</b> indicates studies using the selected determinant did not record the same direction of influence on conditions of water insecurity. The size of the bubbles on the chart represents the number of studies, with larger bubbles indicating that a particular determinant has been studied more frequently.`,
      bubbleYlabelMax: `Consensus`,
      bubbleYlabelMin: `Inconclusive`,
      bubbleCheckbox: `Everyone needs access to clean water. For those with limited access, <span class="tooltip-group"><span class="tooltip-span"> water insecurity </span><span id="water-insecurity-tooltip" class="tooltiptext"> Populations cannot maintain access to adequate quantities of water at an acceptable quality to sustain livelihoods, development, and human and ecosystem health.</span></span> has a daily impact on their lives. People may be more or less vulnerable to water insecurity due to`,
      bubbleLabels: {
        "Demographiccharacteristics": "demographic characteristics",
        "Health": "health",
        "Livingconditions": "living conditions",
        "Socioeconomicstatus": "socioeconomic status",
        "Riskperception": "risk perception",
        "Landtenure": "land tenure",
        "Exposure": "exposure to stressors"
      },
      bubbleCheckboxEnd: `(like drought or pollution).  Below is a chart that displays how certain social vulnerability determinants relate to water insecurity.`,
      appeared: "appeared in",
      singleStudy: `study`,
      multipleStudies: `studies`,
      dendroExplainer: `Click on the topics below to see the different vulnerability indicators studied in relation to water insecurity. Thicker diagram lines indicate more well-studied topics. The number of studies for each indicator are displayed in parentheses.`
    },
    authorSection: {
    text: "This site was created by the <a href='https://labs.waterdata.usgs.gov/visualizations/' target='_blank'>USGS Vizlab</a>. <a href='https://www.usgs.gov/staff-profiles/elmera-azadpour' target='_blank'>Elmera Azadpour</a> led the project, with contributions from <a href='https://wim.usgs.gov/team/' http://localhost:5173/visualizations/vulnerability-indicators/>Aileen Clarke</a>, <a href='https://www.usgs.gov/staff-profiles/amanda-carr' target='_blank'>Mandie Carr</a>, <a href='https://www.usgs.gov/staff-profiles/oronde-drakes' target='_blank'>Oronde Drakes</a>, <a href='https://www.usgs.gov/staff-profiles/diana-l-restrepo-osorio' target='_blank'>Diana Restrepo-Osorio</a>, <a href='https://www.usgs.gov/staff-profiles/cee-nell' target='_blank'>Cee Nell</a>, Yajaira Ayala Alanis, and Paola Rivera Gonzalez."
  }

  }
}