export default {
  pageTitle: "Desigualdad de acceso al agua",
  pageSubtitle: "Por qué los factores sociales determinan el nivel de riesgo de la falta de agua potable",
  readIn: 'Leer en: ',
  components: {
    introNarrative: {
      paragraph1: `Imagine, por ejemplo, que vive en una casa grande de una zona residencial donde el agua potable fluye de cada grifo. Hay suficiente agua para que disfrute con su familia de un bonito jardín cada año. La compañía de agua se ocupa de tratarla y mantener los sistemas de tuberías con regularidad, para asegurarse de que el agua continúe siendo apta para el consumo humano.`,
      paragraph2: `Ahora imagine que vive en una pequeña comunidad rural a las afueras de la ciudad. Tiene su propio pozo, pero, desde hace unos años, usted y sus vecinos han tenido que cavar cada vez más profundo para llegar al nivel del agua. A estas aguas subterráneas se les han ido filtrando metales pesados, producto de aguas residuales industriales y la corrosión de tuberías de cobre soldadas con plomo. Sin embargo, no tiene forma de tratar el agua antes de que su familia la beba. Hay un estanque cercano que cada verano por la falta de agua adquiere un tono verde horrendo a medida que proliferan las algas tóxicas.`,
      paragraph3: `Esta escena puede parecer difícil de creer, pero el acceso inadecuado al agua limpia es la desafortunada realidad para muchos estadounidenses. Más de 2,2 millones de estadounidenses carecen de agua corriente y plomería básica en su hogar <a href='https://www.digdeep.org/draining' target='_blank'>(DigDeep, 2022)</a>, y aproximadamente el 3% de los sistemas de agua comunitarios tienen problemas graves de calidad del agua <a href='https://www.nature.com/articles/s41467-021-23898-z' target='_blank'>(Mueller and Gasteyer, 2021)</a>. El acceso limitado al agua potable puede ser el resultado de un solo acontecimiento, como el <a href='https://storymaps.arcgis.com/stories/7f105650f97e4b20839edb65de3b12ce' target='_blank'>descarrilamiento del tren que transportaba sustancias químicas peligrosas en East Palestine, Ohio,</a> o puede resultar a largo plazo a causa de una infraestructura que se haya ido desgastando, como fue el caso de los <a href='https://www.npr.org/sections/thetwo-way/2016/04/20/465545378/lead-laced-water-in-flint-a-step-by-step-look-at-the-makings-of-a-crisis' target='_blank'>niveles extremadamente peligrosos de plomo en el agua para consumo humano de Flint, Michigan.</a>`,
      paragraph4: `Las poblaciones marginadas a menudo se ven afectadas de manera desproporcionada por la carencia de agua. Las comunidades de color y las personas que viven por debajo del umbral de pobreza suelen ser las más afectadas por <span class="tooltip-group"><span class="tooltip-span">los riesgos relacionados con el agua,</span><span id='water-hazards-tooltip' class="tooltiptext"> un fenómeno natural y una situación en la que existe un peligro para la vida, la salud, el medio ambiente, la propiedad y la sociedad. Algunos ejemplos de riesgos relacionados con el agua son las inundaciones, las sequías y las marejadas ciclónicas.</span></span> ya que carecen de los medios para protegerse adecuadamente. Pueden encontrar trabas para la reubicación o dificultades para ausentarse del trabajo, la falta de sueldo o pagar gastos médicos. En el caso de la crisis de agua en Flint, Michigan, las comunidades de negros y de bajos ingresos, que en ese momento representaban el <a href='https://apnews.com/general-news-7b2bcfdcc8d74ece9e0cb167a2239745' target='_blank'>57% y el 42%</a> de la población de Flint, respectivamente, fueron algunas de las comunidades socioeconómicamente desfavorecidas más afectadas por la exposición al plomo. Independientemente de la causa, el riesgo de experimentar una carencia de agua potable está estrechamente relacionado con el nivel de <span class="tooltip-group"><span class="tooltip-span">riesgo social</span><span id='social-vulnerability-tooltip' class="tooltiptext">Condiciones en las que los factores sociales determinan la exposición a los riegos, la susceptibilidad a sufrir daños y la capacidad para hacer frente a las pérdidas y recuperarse de ellas.</span></span>.`,
    },
    mapText: {
      title: "Indicadores de riesgo en los estados del oeste",
      p1Title: "Tamaño del hogar ",
      paragraph1: "La infraestructura y los elementos institucionales son los factores determinantes principales de acceso y seguridad del suministro de aguas en los Estados Unidos <a href='https://doi.org/10.1029/2023WR036284' target='_blank'>(Drakes y otros, 2024)</a>. <a href='https://wires.onlinelibrary.wiley.com/doi/10.1002/wat2.1486' target='_blank'>Meehan y otros (2020)</a> encontraron que 471 000 hogares o 1,1 millones de personas carecían de acceso a agua corriente entre 2013 y 2017, con la mayoría (73%) de estos hogares ubicados en áreas metropolitanas y casi la mitad (47%) en las 50 mayores áreas urbanas. Los estudios consultados mostraban que indicadores como el tamaño del hogar, las mujeres cabeza de familia, la población femenina y el porcentaje de mujeres en la fuerza laboral se relacionaban positivamente de manera predominante e influían en las condiciones de falta de acceso al agua. A continuación, se muestra un mapa por condados de la media del tamaño de los hogares, de viviendas ocupadas, donde los condados con la media de hogares de mayor tamaño, en azul oscuro, incluyen los condados de Oglala Lakota y de Todd en Dakota del Sur y el condado de Madison en Idaho. ",
      p2Title: "Desigualdad de ingresos",
      paragraph2: "Las personas de bajos ingresos y empobrecidas tienen más probabilidades de experimentar condiciones asociadas con la carencia de agua potable. Además, la desigualdad de ingresos es un predictor muy significativo de la 'pobreza de plomería', es decir, de los hogares que carecen de plomería interior completa <a href='https://www.pnas.org/doi/abs/10.1073/pnas.2007361117' target='_blank'>(Meehan y otros, 2020)</a>.El mapa por condados a continuación muestra la media de ingresos por hogar en los últimos 12 meses (en dólares ajustados a la inflación de 2022). Los condados con la mayor media de ingresos por hogar se muestran en azul oscuro e incluyen los condados de Santa Clara, de San Mateo y de Marín en California.",
      p3Title: "Disparidad en alquileres ",
      paragraph3: "A medida que aumenta el valor medio de los alquileres, la carencia de agua potable tiende a disminuir, lo que seguramente refleja un mayor acceso a recursos para poblaciones más ricas <a href='https://www.sciencebase.gov/catalog/item/63f79d49d34e4f7eda456572' target='_blank'>(Hines y otros, 2023)</a>. Ahora bien, los que alquilan tienden a tener un mayor riesgo de pérdidas por los riesgos relacionados con el agua en comparación con los propietarios de viviendas. Después de un desastre natural, es más probable que los que alquilan se muden y menos probable que soliciten y reciban asistencia. Los que alquilan también suelen carecer de la autoridad y los medios para realizar cambios estructurales en la vivienda para la mitigación, respuesta o recuperación de riesgos, lo que aumenta los riesgos y la susceptibilidad de los que alquilan a la vez que se reduce su capacidad para hacer frente a los mismos <a href='https://doi.org/10.1016/j.ijdrr.2020.102010' target='_blank'>(Drakes y otros, 2021) </a>.",
      p4Title: "Poblaciones hispanas ",
      paragraph4: "Las poblaciones hispanas corren un mayor riesgo de carencia de agua potable <a href='https://www.sciencebase.gov/catalog/item/63f79d49d34e4f7eda456572' target='_blank'>(Hines y otros, 2023)</a>.En algunas áreas del país, los hogares hispanos tienen más probabilidades de experimentar una 'pobreza en plomería'<a href='https://www.pnas.org/doi/abs/10.1073/pnas.2007361117' target='_blank'>(Meehan y otros, 2020)</a>—particularmente en el oeste de los Estados Unidos.De hecho, las investigaciones muestran que, aunque los hogares con cabeza de familia hispano representan menos del 13% de todos los hogares de los EE. UU., representan casi el 17% de los hogares con plomería sin terminar <a href='https://doi.org/10.1080/24694452.2018.1530587' target='_blank'>(Deitz y Meehan, 2019)</a>. El mapa por condados a continuación muestra el porcentaje de poblaciones hispanas donde los condados con el mayor porcentaje de hispanos, en azul oscuro, incluyen los condados de Kenedy, de Starr y de Webb en Texas. Estas áreas se ven particularmente afectadas por la combinación de los desafíos de la carencia de agua potable y la pobreza de plomería.",
      p5Title: "Poblaciones discapacitadas",
      paragraph5: "Las poblaciones con necesidades especiales y discapacidades pueden vivir en lugares más expuestos a riesgos relacionados con el agua <a href='https://www.sciencedirect.com/science/article/abs/pii/S0277953619301121' target='_blank'>(Chakraborty y otros, 2019)</a>o experimentar un abastecimiento de agua potable poco fiable o intermitente <a href='https://journals.plos.org/plosone/article?id=10.1371/journal.pone.0155043' target='_blank'>(White y otros, 2016)</a>. Por ejemplo, <a href='https://doi.org/10.1029/2023WR036284' target='_blank'>Drakes y otros (2024)</a> encontraron que las poblaciones con necesidades especiales y discapacitadas estaban asociadas con una mayor probabilidad de condiciones de carencia de agua potable en el oeste de los Estados Unidos. Sin embargo, solo dos estudios han medido la relación entre la discapacidad y la falta de agua, y esta investigación sobre el tema se limitó solo al sector de aguas municipales. El mapa a continuación muestra el porcentaje de personas discapacitadas por condados, donde los condados con el mayor porcentaje de discapacitados, en azul oscuro, incluyen los condados de Catron y de Mora en Nuevo México y el condado de Kinney en Texas."
    },
    metaAnalysisText: {
      title: "Metaanálisis del riesgo de la falta de agua potable",
      paragraph1: `Los investigadores del programa de Impulsores Sociales y Económicos de USGS <a href="https://www.usgs.gov/data/literature-summary-indicators-water-vulnerability-western-us-2000-2022" target="blank">identificaron factores de riesgo social asociados con las condiciones de carencia de agua potable</a>. El equipo centró su análisis en estudios realizados entre 2000 y 2022 en los estados colindantes (los 48 estados inferiores) al oeste del río Misisipi. Los estados del oeste se enfrentan a una serie de desafíos de disponibilidad de agua, incluido el aumento del crecimiento de la población, la dependencia de aguas subterráneas y una escasez regular de precipitación (véase <a href='https://pubs.usgs.gov/circ/2005/circ1261/pdf/C1261.pdf' target="blank">Anderson y Woosley 2005 </a> para un análisis de la disponibilidad de agua en el oeste de los Estados Unidos).`,
      paragraph2: `El equipo descubrió que se había estudiado muy bien un pequeño subconjunto de factores de riesgo social que se asociaba sistemáticamente con la carencia de agua potable. Estos factores incluían múltiples características demográficas (edad, raza/etnia, estructura familiar, género y dominio del idioma), dependencia de fuentes y usos específicos del agua, riqueza y exposición a riesgos relacionados con el agua.`,
      paragraph3: `Sin embargo, estos factores no se distribuyen de manera equitativa en el oeste de los Estados Unidos. Por ejemplo, ciertas razas y etnias se concentran más en algunas áreas geográficas que en otras. De manera similar, algunos condados tienen una media de ingresos por hogar mucho más baja que otros condados. Comprender dónde viven estas poblaciones vulnerables es clave para que los administradores de recursos hídricos tomen decisiones equitativas sobre la disponibilidad y el uso del agua. A continuación, se describen con más detalle algunos de los factores que este estudio consideró significativos en los estados del oeste.`
    },
    socialVulnerabilityText: {
      title: "¿Cuál es el siguiente paso?",
      paragraph1: `Un área de investigación crucial, y en gran medida por explorar, es <span class='tooltip-group'><span class='tooltip-span'>la interseccionalidad</span><span id='intersectionality-tooltip' class='tooltiptext'>Forma compleja y acumulativa en que los efectos de múltiples formas de discriminación se combinan, superponen o se entrecruzan, especialmente en las experiencias de individuos o grupos marginados.</span></span> de los factores de riesgo social. Los factores evaluados por los investigadores de USGS representan impulsores individuales de la carencia de agua potable, como el tamaño del hogar o el origen étnico. ¿Qué pasa con las personas que experimentan múltiples factores de riesgo al mismo tiempo? Por ejemplo, "las personas mayores que tienen ingresos más bajos son una población única, en la que se solapan, pero es distinta de las poblaciones solo de ancianos o solo de ingresos más bajos", dice Oronde Drakes, geógrafo social de USGS y autor principal del <span class="tooltip-group"><span class="tooltip-span">metaanálisis</span><span id="meta-analysis-tooltip" class="tooltiptext">Tipo de estudio de revisión en el que los investigadores combinan datos de muchos estudios diferentes para tratar de identificar patrones más generales de todos los resultados.</span></span>. "La interacción de esas características sociales puede tener impactos diferentes y significativos en el acceso seguro a agua potable de los que se encuentren con esos factores sociales por separado".`,
      paragraph2: "En este creciente campo del riesgo social de la falta de agua potable, aún queda mucho por aprender. Una comprensión más profunda no solo de dónde ocurre esta carencia, sino también de quién es más vulnerable y por qué, mejorará la capacidad de abordar los problemas de justicia ambiental <span class='tooltip-group'><span class='tooltip-span'>los problemas de justicia ambiental</span><span id='environmental-justice-tooltip' class='tooltiptext'>Planificación, actividades e información científicas destinadas a apoyar el acceso y el uso equitativos por parte de todas las personas que puedan verse afectadas.</span></span> y equidad en los recursos hídricos."
    },
    teamText: {
      title: "Quiénes somos",
      paragraph1: "El equipo de Impulsores Sociales y Económicos de USGS está formado por científicos sociales, geógrafos e hidrólogos que realizan estudios interdisciplinarios para comprender las interacciones e interdependencias de los sistemas humanos y naturales con respecto a los sectores de uso del agua. El propósito de este proyecto es predecir y medir los riesgos sociales que impiden el acceso seguro al agua potable para evaluar y tratar mejor los riesgos para una gestión del agua adaptativa."
    },
    chartText: {
      bubbleText: "Interactúe con el gráfico para ver diferentes muestras<br>de los factores determinantes de riesgo social.",
      bubbleLegend: `Se han estudiado muchos factores determinantes de riesgo social. Algunos muestran relaciones positivas <span class="legend-box positive"></span> con la carencia de agua, otros negativas <span class="legend-box negative"></span>, y otros desconocidas <span class="legend-box unknown"></span> <a href='https://www.sciencebase.gov/catalog/item/63f79d49d34e4f7eda456572' target='_blank'>(Hines y otros, 2023</a>; <a href='https://doi.org/10.1029/2023WR036284' target='_blank'>Drakes y otros, 2024)</a>`,
      bubbleYaxis: `El eje Y del gráfico representa el nivel de acuerdo entre los estudios, donde el aumento del <b>consenso</b> indica que la mayoría de los estudios que utilizaron el factor determinante seleccionado indicaron el mismo tipo de influencia en las condiciones de carencia de agua y <b>no concluyentes</b> indica que los estudios que utilizaron el factor determinante seleccionado no indicaron un mismo tipo de influencia en las condiciones de carencia de agua. El tamaño de las burbujas en el gráfico representa el número de estudios, y las burbujas más grandes indican que un factor determinante particular se ha estudiado con más frecuencia.`,
      bubbleYlabelMax: `Consenso`,
      bubbleYlabelMin: `No concluyentes`,
      bubbleCheckbox: `Todo el mundo necesita acceso a agua potable. For those with limited access, <span class="tooltip-group"><span class="tooltip-span"> carencia de agua potable </span><span id="water-insecurity-tooltip" class="tooltiptext">La población no puede mantener el acceso a cantidades adecuadas de agua de una calidad aceptable para mantener la subsistencia, el desarrollo y la salud humana y de los ecosistemas.</span></span> has a daily impact on their lives. El grado en que las personas experimentan la carencia de agua potable varía según `,
      bubbleLabels: {
        "Demographiccharacteristics": "las características demográficas",
        "Health": "la salud",
        "Livingconditions": "las condiciones de vida",
        "Socioeconomicstatus": "el estatus socioeconómico",
        "Riskperception": "la percepción del riesgo",
        "Landtenure": "la tenencia de la tierra",
        "Exposure": "la exposición a fuentes de estrés"
      },
      bubbleCheckboxEnd :` (como la sequía o la contaminación). A continuación, hay un gráfico que muestra cómo ciertos factores determinantes de riesgo social se relacionan con la falta de agua.`,
      appeared: "apareció en",
      singleStudy: `estudio`,
      multipleStudies: `estudios`,
      dendroExplainer: `Haga clic en cada tema para ver los diferentes indicadores de riesgo estudiados en relación con la carencia de agua. Las líneas más gruesas del diagrama indican temas mejor estudiados. El número de estudios de cada indicador se muestra entre paréntesis.`
    },
    authorSection: {
    text: "Este sitio fue creado por el <a href='https://labs.waterdata.usgs.gov/visualizations/' target='_blank'>USGS Vizlab</a>. <a href='https://www.usgs.gov/staff-profiles/elmera-azadpour' target='_blank'>Elmera Azadpour</a> dirigió el proyecto, con contribuciones de <a href='https://wim.usgs.gov/team/' target='_blank'>Aileen Clarke</a>, <a href='https://www.usgs.gov/staff-profiles/amanda-carr' target='_blank'>Mandie Carr</a>, <a href='https://www.usgs.gov/staff-profiles/oronde-drakes' target='_blank'>Oronde Drakes</a>, <a href='https://www.usgs.gov/staff-profiles/diana-l-restrepo-osorio' target='_blank'>Diana Restrepo-Osorio</a>, <a href='https://www.usgs.gov/staff-profiles/cee-nell' target='_blank'>Cee Nell</a>, Yajaira Ayala Alanis, y Paola Rivera Gonzalez."
  }

  }
}